//////////////////////////////////////////////////////////////
// This file is generated from the Minecraft documentation. //
// DO NOT EDIT THIS FILE! YOUR CHANGES WILL BE OVERWRITTEN! //
//////////////////////////////////////////////////////////////

/// <reference path="./client_events.generated.d.ts" />

declare interface IClientSystem<TSystem> {
    
    ////////////////////////////////////////////////
    // Blocks
    ////////////////////////////////////////////////
    /**
     * Allows you to get a block from the world when provided an x, y, and z position. The block must be within a ticking area.
     * @param tickingArea The ticking area the block is in
     * @param x The x position of the block you want
     * @param y The y position of the block you want
     * @param z The z position of the block you want
     * @return object An object containing the block
     * @return null Something went wrong when retrieving the block
     */
    getBlock(tickingArea: ITickingArea, x: number, y: number, z: number): IBlock | null;
    /**
     * Allows you to get a block from the world when provided a JavaScript object containing a position. The block must be within a ticking area.
     * @param tickingArea The ticking area the block is in
     * @param positionObject A JavaScript object with the x, y, and z position of the block you want
     * @return object An object containing the block
     * @return null Something went wrong when retrieving the block
     */
    getBlock(tickingArea: ITickingArea, positionObject: VectorXYZ): IBlock | null;
    /**
     * Allows you to get an array of blocks from the world when provided a minimum and maximum x, y, and z position. The blocks must be within a ticking area.
     * @param tickingArea The ticking area the blocks are in
     * @param xMin The minimum x position of the blocks you want
     * @param yMin The minimum y position of the blocks you want
     * @param zMin The minimum z position of the blocks you want
     * @param xMax The maximum x position of the blocks you want
     * @param yMax The maximum y position of the blocks you want
     * @param zMax The maximum z position of the blocks you want
     * @return undefined A 3D array of block objects. Indexs are the blocks positions relative to the min position given
     * @return null Something went wrong when retrieving the blocks
     */
    getBlocks(tickingArea: ITickingArea, xMin: number, yMin: number, zMin: number, xMax: number, yMax: number, zMax: number): IBlock[][] | null;
    /**
     * Allows you to get an array of blocks from the world when provided a minimum and maximum position. The blocks must be within a ticking area.
     * @param tickingArea The ticking area the blocks are in
     * @param minimumPositionObject A JavaScript object with the minimum x, y, and z position of the blocks you want
     * @param maximumPositionObject A JavaScript object with the maximum x, y, and z position of the blocks you want
     * @return undefined A 3D array of block objects. Indexs are the blocks positions relative to the min position given
     * @return null Something went wrong when retrieving the blocks
     */
    getBlocks(tickingArea: ITickingArea, minimumPositionObject: VectorXYZ, maximumPositionObject: VectorXYZ): IBlock[][] | null;
    
    ////////////////////////////////////////////////
    // Components
    ////////////////////////////////////////////////
    /**
     * Removes the specified component from the given entity. If the entity has the component, it will be removed. Currently this only works with custom components and can't be used to remove components defined for an entity in JSON.
     * @param entityObject The EntityObject that was retrieved from a call to createEntity() or retrieved from an event
     * @param componentIdentifier The identifier of the component to remove from the entity. This is either the identifier of a built-in component (check the Script Components section) or a custom component created with a call to registerComponent()
     * @return true The component was successfully removed from the entity
     * @return null The entity did not have the component or something went wrong when removing the component
     */
    destroyComponent(entityObject: IEntity, componentIdentifier: string): true | null;
    /**
     * Checks if the given entity has the specified component.
     * @param entityObject The EntityObject that was retrieved from a call to createEntity() or retrieved from an event
     * @param componentIdentifier The identifier of the component to check on the entity. This is either the identifier of a built-in component (check the Script Components section) or a custom component created with a call to registerComponent()
     * @return true The EntityObject has the component
     * @return false The EntityObject doesn't have the component
     * @return null An unknown component was passed in or something else went wrong when checking if the EntityObject had the component
     */
    hasComponent(entityObject: IEntity, componentIdentifier: string): true | false | null;
    
    ////////////////////////////////////////////////
    // Entities
    ////////////////////////////////////////////////
    /**
     * Creates an empty entity with no components and does not place it in the world. The empty entity will be of type custom and have a blank identifier. This is NOT a valid entity that exists in the world, just an empty one that only scripts know about.
     * 
    NOTE: Entities are created first on the server, with the client notified of new entities afterwards. Be aware that if you send the result object to the client right away, the created entity might not exist on the client yet.
     * 
     * @return object An object representing the newly created entity
     * @return null Something went wrong when creating the entity
     */
    createEntity(): IEntity | null;
    /**
     * Creates an entity and applies the specified template as defined in JSON. This allows you to quickly create an entity from the applied Behavior Packs as the base for an entity created in scripting. The entity will be spawned into the world with all the components, component groups, and event triggers that are defined in the JSON file of the identifier specified. Only works on scripts registered on the server.NOTE: Entities are created first on the server, with the client notified of new entities afterwards. Be aware that if you send the result object to the client right away, the created entity might not exist on the client yet.
     * @param type Specifies the type of the entity that is being created by the template. Valid inputs are `entity` and `item_entity`
     * @param templateIdentifier This can be any of the entity identifiers from the applied Behavior Packs. For example specifying minecraft:cow here will make the provided entity a cow as defined in JSON
     * @return object An object representing the newly created entity
     * @return null Something went wrong when creating the entity
     */
    createEntity(type: string, templateIdentifier: string): IEntity | null;
    /**
     * Destroys an entity identified by the EntityObject. If the entity exists in the world this will remove it from the world and destroy it. This also makes the EntityObject no longer valid - you should only destroy an entity after you are done with it and no longer need to reference it again. This does NOT kill the entity. There won't be an event for its death: it will be removed.
     * @param entityObject The object that was retrieved from a call to createEntity() or retrieved from an entity event
     * @return true The entity was successfully destroyed
     * @return null Something went wrong when destroying the entity
     */
    destroyEntity(entityObject: IEntity): true | null;
    /**
     * Checks if the given EntityObject corresponds to a valid entity.
     * @param entityObject The object that was retrieved from a call to createEntity() or retrieved from an entity event
     * @return true The entity is in the Script Engine's database of entities
     * @return false The entity is not in the Script Engine's database of entities
     * @return null Something went wrong when validating the entity
     */
    isValidEntity(entityObject: IEntity): true | false | null;
}
